@@ -314,15 +314,18 @@ function dcpFormatGMotion(data, jqXHR) {
 }
 
 //----------------------------------------------------------------------
-var item2key = {};
+var hitem2key = {};
 function dcpFormatHiChart(data, jqXHR) {
     //-- parse data
-    data  = $.parseJSON(data);
-    qinfo = data.qinfo;
+    //data  = $.parseJSON(data);
+    //qinfo = data.qinfo;
+
+    if ( !(data = dcpParseFlat(data,{mode:"bubble"})) ) { return; }
     if (data.profiles.length == 0) {
 	dcpErrorMsg("Error: no data to display!");
 	return;
     }
+    dcpStatusMsg("loading","Rendering...");
 
     //-- setup plot data
     var cdata = { //-- chart data
@@ -359,44 +362,15 @@ function dcpFormatHiChart(data, jqXHR) {
                 cursor: 'pointer',
                 point: {
                     events: {
-			//-- popup callback on point-click: include ddc links
-                        click: function (e) {
-			    var content = '<table class="dcslide"><tr><th>score:</th><td>' + this.y + '</td></tr>';
-			    var item    = [String(this.label)].concat(item2key[this.series.name].split("\t"));
-			    if (isDiff) {
-				content += (''
-					    +'<tr><th>search:</th><td>'
-					    + kwiclink({"tr":item,"ilabel":0,
-							"qtemplate":qinfo.aqtemplate,"text":"KWIC:A","dtrim":/[^0-9].*$/,"dslice":user_query.slice,
-							"title":"DDC KWIC search for point pairs (QUERY)"
-						       })
-					    + '&#xa0;'
-					    + kwiclink({"tr":item,"ilabel":0,
-							"qtemplate":qinfo.bqtemplate,"text":"KWIC:B","dtrim":/^.*[^0-9]/,"dslice":user_query.bslice,
-							title:"DDC KWIC search for point pairs (~QUERY)"
-						       })
-					    + '</td></tr>'
-					   );
-			    } else {
-				content += (''
-					    +'<tr><th>search:</th><td>'
-					    + kwiclink({"tr":item,"ilabel":0,"qtemplate":qinfo.qtemplate,"text":"KWIC",
-							title:"DDC KWIC search for point pairs"})
-					    + '</td></tr>'
-					   );
+			click: function (e) {
+			    dcur  = dlabels.indexOf(String(this.label).replace(/\./g,"-"));
+			    var idata = items[ itemid[this.series.name.replace(/\//g,"\t")] ];
+			    var dopts = {};
+			    if (!$("#profileDataPopup").is(":visible")) {
+				dopts.position = {at:"center", of:e}
 			    }
-			    content += '</table>';
-
-                            hs.htmlExpand(null, {
-				pageOrigin: {
-				    x: e.pageX || e.clientX,
-				    y: e.pageY || e.clientY
-				},
-                                headingText: this.series.name + ' (' + this.label + ')',
-                                maincontentText: content
-                                /*width: 200*/
-                            });
-                        }
+			    d3InfoPopup(idata, dopts);
+			}
                     }
                 },
                 marker: {
@@ -407,53 +381,16 @@ function dcpFormatHiChart(data, jqXHR) {
 	series: []
     };
 
-    //-- get item and date labels
-    var items  = {}; // { item: { "ADATE.BDATE": score, ... }, ... }
-    var xvals  = []; // ["ADATE.BDATE", ... ]
-    var xval, scoref, key, item;
-    data.profiles.forEach(function(p) {
-	p.label = String(p.label);
-	xval = p.label.replace('-','.');
-	xvals.push(xval);
-
-	scoref = p.score;
-	for (key in p[scoref]) {
-	    item = key.replace(/\t/g,'/');
-	    if (items[item] == null) {
-		items[item] = {};
-		item2key[item] = key;
-	    }
-	    items[item][xval] = p[scoref][key];
+    //-- create hicharts series
+    var item, di, score;
+    items.forEach(function(item) {
+	item.hiseries = { name:item.label, data:[] };
+	for (var di in dlabels) {
+	    score = item.score[di];
+	    item.hiseries.data.push({x:Number(String(dlabels[di]).replace(/-/g,".")), y:(score==null ? null : score), label:dlabels[di]});
 	}
+	cdata.series.push(item.hiseries);
     });
-    var ikeys = keys(items).sort();
-    var i2series = {};
-    ikeys.forEach(function(item) {
-	i2series[item] = { name:item, data:[] };
-    });
-
-    //-- check for empty item-set (in case we had only empty profiles)
-    if (ikeys.length==0) {
-	dcpErrorMsg("Error: no items to display!");
-	return;
-    }
-    
-    //-- chart: series scores
-    var idata, yval;
-    for (item in items) {
-	idata = i2series[item];
-	xvals.forEach(function(xval) {
-	    yval = items[item][xval];
-	    i2series[item].data.push({x:Number(xval), y:(yval==null ? null : yval), label:xval.replace('.','-')});
-	});
-    }
-
-    //-- finalize series
-    cdata.series = ikeys.map(function(item) { return i2series[item]; });
-    /*
-    ikeys.forEach(function(item) {
-	cdata.series.push(i2series[item]);
-    });*/
 
     //-- setup plot area 
     $(".rawURL").hide();
@@ -461,6 +398,7 @@ function dcpFormatHiChart(data, jqXHR) {
 
     //-- plot the chart
     $("#profileDataChart").addClass("hcChart").highcharts(cdata).show();
+    dcpClearMsg();
 }
 
 //----------------------------------------------------------------------
@@ -732,9 +670,10 @@ function d3NodeTitleText(d) {
 
 //--------------------------------------------------------------
 // d3: info popup
-function d3InfoPopup(d) {
+function d3InfoPopup(d,opts) {
     var dsnap  = Math.round(dcur);
     var dlabel = dlabels[dsnap];
+    
 
     //-- save current info item
     d3InfoCur = {data:d};
@@ -758,6 +697,13 @@ function d3InfoPopup(d) {
     if (!$("#profileDataPopup").is(":visible")) {
 	dopts.position = {at:"center",of:this};
     }
+    for (var o in opts) {
+	if (o == null) {
+	    delete dopts[o];
+	} else {
+	    dopts[o] = opts[o];
+	}
+    }
 
     var content = (''
 		   +'<span class="ui-helper-hidden-accessible"><input type="text"/></span>' //-- disable ugly jquery-ui autofocus
